==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fDload.h <==
// class soot.coffi.Instruction_Dload

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 1a2df1032743555a soot_coffi_Instruction__5fDload
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fDload_H_
#define _JC_soot_coffi_Instruction__5fDload_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fDload$sub_refs	_jc_soot_coffi_Instruction__5fDload$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fDload$sub_nonrefs	_jc_soot_coffi_Instruction__5fDload$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fDload$refs	_jc_soot_coffi_Instruction__5fDload$refs;
typedef struct _jc_soot_coffi_Instruction__5fDload$nonrefs	_jc_soot_coffi_Instruction__5fDload$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fDload$object	_jc_soot_coffi_Instruction__5fDload$object;

typedef const struct _jc_soot_coffi_Instruction__5fDload$vmethods	_jc_soot_coffi_Instruction__5fDload$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fDload$vtable	_jc_soot_coffi_Instruction__5fDload$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fDload$vtype	_jc_soot_coffi_Instruction__5fDload$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fDload$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fDload$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fDload$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fDload$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fDload$vmethods	soot_coffi_Instruction__5fDload;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fDload$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fDload$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fDload$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fDload$refs {
    _jc_soot_coffi_Instruction__5fDload$sub_refs	soot_coffi_Instruction__5fDload;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fDload$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fDload$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fDload$sub_nonrefs	soot_coffi_Instruction__5fDload;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fDload$object {
	_jc_soot_coffi_Instruction__5fDload$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fDload$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fDload$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fDload$vtype _jc_soot_coffi_Instruction__5fDload$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fDload, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fDload$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fDload_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fDload.h <==
// class soot.coffi.Instruction_Dload

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 1a2df1032743555a soot_coffi_Instruction__5fDload
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fDload_H_
#define _JC_soot_coffi_Instruction__5fDload_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fDload$sub_refs	_jc_soot_coffi_Instruction__5fDload$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fDload$sub_nonrefs	_jc_soot_coffi_Instruction__5fDload$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fDload$refs	_jc_soot_coffi_Instruction__5fDload$refs;
typedef struct _jc_soot_coffi_Instruction__5fDload$nonrefs	_jc_soot_coffi_Instruction__5fDload$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fDload$object	_jc_soot_coffi_Instruction__5fDload$object;

typedef const struct _jc_soot_coffi_Instruction__5fDload$vmethods	_jc_soot_coffi_Instruction__5fDload$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fDload$vtable	_jc_soot_coffi_Instruction__5fDload$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fDload$vtype	_jc_soot_coffi_Instruction__5fDload$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fDload$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fDload$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fDload$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fDload$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fDload$vmethods	soot_coffi_Instruction__5fDload;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fDload$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fDload$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fDload$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fDload$refs {
    _jc_soot_coffi_Instruction__5fDload$sub_refs	soot_coffi_Instruction__5fDload;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fDload$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fDload$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fDload$sub_nonrefs	soot_coffi_Instruction__5fDload;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fDload$object {
	_jc_soot_coffi_Instruction__5fDload$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fDload$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fDload$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fDload$vtype _jc_soot_coffi_Instruction__5fDload$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fDload, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fDload$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fDload_H_ */
